---
title: 결제 데이터 분석 가이드
category: 관리자콘솔 (관리자콘솔 사용 가이드) > 결제 데이터 분석 > 결제 데이터 분석
seo:
  title: 결제 데이터 분석 가이드
  description: >-
    결제 데이터 기반 인사이트 제공으로, 고객사가 더욱 빠른 의사결정을 할 수 있도록 돕는 결제 데이터 기반 분석 대시보드인 포트원 결제
    데이터 분석을 확인해보세요.
  keywords:
    - 관리자콘솔
    - 애널리틱스
    - 포트원
    - 결제데이터분석
tags:
  - 공통
  - 결제데이터분석
pgCompanies:
  - 공통
searchTags:
  - 기간데이터
  - 거래데이터
  - 결제대시보드
  - 결제모니터링
  - 결제현황
  - 결제분석
  - 결제데이터분석
---

### **결제 데이터 분석 서비스 소개**

- 포트원 결제 데이터 분석은 결제 데이터 기반으로 인사이트를 제공하여 고객사에서 빠른 의사결정을 할 수 있도록 돕는 결제 데이터 기반 분석 대시보드입니다.
- 포트원 전자결제 서비스를 이용하는 모든 고객은 추가적인 개발 없이 베타 서비스 신청 후 이용할 수 있습니다.
- 현재 기간 한정으로 무료로 사용하실 수 있으며, 추후 유료 전환될 예정입니다.



### **사용설명서**

#### **1.결제 데이터 기반 대시보드**

- **조건 지정**

<Indent level="1">

- 기간 선택
  - 버튼식 날짜 혹은 캘린더 뷰에서 원하는 기간을 선택할 수 있으며, 2014년부터 그 이후의 데이터에 한하여 표기합니다.
- 통화 선택
  - 통화는 KRW, USD, JPY, EUR, CNY , TWD, AUD, THB, HKD 중에 선택할 수 있습니다.
  - 국내결제(KRW)만 사용하고 계실 경우, KRW 만 노출합니다.
  - 해외결제를 사용하고 계실 경우, KRW, USD, JPY, EUR, CNY , TWD, AUD, THB, HKD가 모두 노출되며, 베타 서비스에서는 실제 사용 통화에 관계없이 대표적 통화 9개 기준으로 표기합니다.
- 순 거래액 보기 토글: 총 거래액 혹은 순 거래액 표기 기준을 지정합니다.
  - on: 취소 및 환불 완료된 이후의 순 거래액
  - off: 최초 결제 완료된 총 거래액
  - 토글은 거래 건수에는 영향을 주지 않습니다. 거래 건수는 거래 기간 내 승인된 모든 거래 건수를 의미하며, 전체/부분 취소된 거래 건도 포함합니다.

</Indent>

- **거래 데이터 표기 기준**

<Indent level="1">

- 데이터 최종 업데이트
  - PG사별 결제 상태 승인 시각을 기준으로 내역이 업데이트 됩니다.
  - 데이터 최종 업데이트 기준은 콘솔 사용자의 진입 시간의 직전 ‘시’의 데이터로 노출됩니다. 예) 12:20 진입 시, 11:00까지의 데이터 호출
  - 결제 데이터 분석에서 제공하는 결제 데이터는 업데이트되는 시간으로 인해 관리자 콘솔 내 결제 - 상세내역조회 → 결제내역 섹션과 데이터가 소폭 상이할 수 있습니다.
- 거래액
  - 총 거래액 (순 거래액 보기 토글 off) : 검색한 기간 내 발생한 모든 결제승인 거래건의 결제 합계 금액
  - 순 거래액 (순 거래액 보기 토글on) : 검색한 기간 내 발생한 모든 결제승인 거래건의 결제 합계 금액 - 검색한 기간 내 발생한 모든 부분취소/전체취소 승인 거래건의 취소 금액 합계
- 거래 건수 : 거래 기간 내 승인된 모든 거래 건수 (전체/부분 취소된 거래 건도 포함
- 기간 내 취소 및 환불률 : 조회된 기간 내 (총 거래액 - 순 거래액) / 총 거래액으로 계산됩니다.
- 비교 기간: 비교 기간이란, 선택 기간에 해당 하는 길이 만큼의 직전 혹은 상대적 기간 데이터를 기준으로 합니다. 결제 현황 페이지에만 적용됩니다.
  - 일반 (직전 기간 비교) - 최근 4주, 최근 3개월, 최근 6개월 버튼 포함
    - 선택 기간에 포함되는 길이만큼 직전 기간의 동일한 일자 길이를 비교합니다.
  - 오늘 - 버튼식 (상대적 기간 비교)
    - 오늘 00시부터 현재까지와 어제 00시부터 동일 시점까지를 비교합니다.
  - 이번 달 - 버튼식 (상대적 기간 비교)
    - 이번 달 시작 시점 00시부터 어제까지와 지난 달 시작 시점 00시부터 동일한 일자 길이를 비교합니다.
  - 올해 - 버튼식 (상대적 기간 비교)
    - 올해 시작 시점 00시부터 어제까지와, 지난해 시작 시점 00시부터 동일한 일자 길이를 비교합니다.
- 제외 데이터
  - 거래액, 거래건수 표기에 테스트 결제건, 결제 실패건, 결제 예정건은 제외됩니다.
- 음수 데이터
  - case) 음수(-) 거래액과 0 건수 발생
    - ‘결제건수’는 결제완료 승인 건을 기준으로 집계되며, 선택한 기간에 결제 전체취소 혹은 결제 부분취소 건만 존재하는 경우, 건수는 0이고 거래액은 음수로 표기될 수 있습니다.

</Indent>

- **기간 데이터 표기 기준**

<Indent level="1">

- 기간 데이터 표기는 YYYY/MM/DD 를 기준으로 하며, 시간은 취급하지 않습니다.
- 최근 xx일
  - 오늘을 제외한 최근 xx일 기준을 표기합니다.
  - 예) 최근 7일은 최근 8일 \~ 어제까지의 데이터를 포함합니다.
- 이번 달, 올해
  - 오늘을 제외한 1일 \~ 어제까지의 기준을 표기합니다.
  - 예) 8월 15일 기준, 이번 달은 8월 1일 \~ 14일 데이터를 포함합니다.
  - 예) 8월 15일 기준, 올해는 1월 1일 \~ 8월 15일 데이터를 포함합니다.
- 오늘
  - 선택한 날짜가 ‘오늘’일 경우, 0시 부터 최종 업데이트 시간까지의 기준을 표기합니다.
  - 예) 오늘 15시 검색 기준, 오늘 0시 \~ 15시 데이터를 표기합니다.

</Indent>

#### **2. 상세 페이지**

**Section 1. 결제현황**

- 목적
  - 원하는 날짜별로 거래 현황을 확인하고 변화 추이를 그래프로 한눈에 쉽고 간편하게 파악할 수 있습니다.



- 요소별 표기 기준
  - 선택한 기간 중 평균 거래액이 가장 많이 혹은 적게 발생하는 월간, 주간, 일간 시간대를 표기합니다.
  - 거래액 인사이트는 상단 필터에서 선택한 기간 내 평균 거래액으로 산출되어 표기되며, 선택한 기간에 발생한 거래액이 충분하지 않을 경우, 표기가 되지 않을 수 있습니다.
  - 동일한 금액의 거래액이 여러 시점에 발생했을 경우, 인사이트는 선택 기간 내 가장 먼저 발생한 시점을 기준으로 표기됩니다.

* 그래프
  - 실선: 조회한 날짜에 대해 표기합니다
  - 점선: 조회한 날짜 대비 이전 비교 기간을 표기합니다.

- 거래액
  - 순 거래액 보기 `on `: 검색한 기간 내 발생한 모든 결제승인 거래건의 결제 합계 금액 - 검색한 기간 내 발생한 모든 부분취소/전체취소 승인 거래건의 취소 금액 합계
  - 순 거래액 보기 `off`: 검색한 기간 내 발생한 모든 결제승인 거래건의 결제 합계 금액

* 거래건수
  - 거래 기간 내 승인된 모든 거래 건수 (전체/부분 취소된 거래 건도 포함)

- 건당 평균 거래액
  - (총 거래액 / 총 거래건수)

* 고객당 평균 거래액
  - (총 거래액 / 총 고객수)
  - 고객은 휴대폰 번호로 구분되며, 고객당 평균 거래액은 휴대폰 정보 있는 결제 건에 대해서만 집계됩니다.
  - 고객당 평균 거래액 계산은 데이터 베이스의 자동 계산 로직으로 인해 1% 내외의 오차가 있을 수 있습니다.

**Section 2. 결제수단**

- 목적
  - 사용하고 있는 전체 결제수단별 순위 및 기간별 변화 추이를 확인하고 어떤 결제수단이 인기있는지 파악할 수 있습니다.



- **데이터 표기 기준**
  - 카드결제 : 결제 요청시 지정된 결제수단 (pay\_method) 값이 card로 지정된 거래입니다.
  - 간편결제 : 결제요청시 지정된 결제수단 (pay\_method)이나 결제대행사(pg\_provider)가 간편결제(예: naverpay , kakaopay) 로 지정된 거래입니다.
    - 결제 데이터 분석의 간편결제는 허브형 혹은 직계약에 상관없이 최종 상세 결제 수단으로 표기됩니다. (예: 카카오페이, 네이버페이)
    - 참고
      - 간편결제를 허브형으로 이용한 경우, 포트원 관리자 콘솔은 아래와 같이 별도 표기합니다.
        - 결제대행사는 `허브형 계약된 결제대행사`로 노출 (ex: 결제대행사: KCP)
        - 결제내역 상세 모달 내 결제대행사는 결제대행사 허브형ㅣ간편결제로 노출 (ex: 결제대행사: KCP 허브형 ㅣ 네이버페이 결제형)

* **\[전체 결제수단] 페이지**
  - **국내결제**
    - 국내 결제수단 종류는 `카드결제` `간편결제` `실시간 계좌이체` `가상계좌` 휴대폰` 소액결제` `상품권` 6가지이며, \
      6가지 결제수단 중 선택한 기간 내에 결제가 발생한 결제수단만 노출합니다.
  - **해외결제**
    - 해외결제 결제수단 종류는 카드결제 계좌이체 기타 3가지이며, \[전체 결제수단] 페이지 내에서는 3가지 결제수단 중 선택한 기간 내에 결제가 발생한 결제수단만 노출합니다.
      - pay\_method = card `카드결제`
      - pay\_method = transfer `계좌이체`
      - pay\_method = card 혹은 transfer가 아닌 것 `기타`
    - 기타 결제수단은 카드와 계좌이체를 제외한 현지 결제수단 및 간편결제를 의미합니다.
      - paymentwall의 경우, paymentwall에서 제공해주는 emb\_pg\_provider 리스트를 기반으로 합니다.

<Callout icon="💡" content="alipay, alipayplus, coinbasebitcoin, boostwallet, cherrycredits, danawallet, dokuwallet, ezpay, fasterpay, gcashph, gocpay, gopay, grabpayph, grabpaymalay, jeniuspay, kakaopaykr, lpay, linepay, linkaja, mcash, mercadopago, mobilemoneytanzania, mobilewalletseg, mycardwallet, krnaverepay, ovoid, pagaewallet, paycokr, paymayaph, paypal, paytmwallet, qrisid, linepayth, redcompra, sakuku, samsungpay, shopeepay, shopeepayph, shopeepayth, singteldash, twpay, promptpayth, tosspay, tngewallet, truemoneyth, wechatpayments, yandexmoney, ninepay" title=" emb_pg_provider 리스트" />

- **\[카드결제] \[간편결제] 상세 페이지**
  - 카드결제와 간편결제의 경우, 상세 페이지를 통해 각 카드사별, 간편결제사별 날짜별 추이를 파악할 수 있습니다. 소비자가 선호하는 카드사와 간편결제사 측정에 용이합니다.
  - 전체 카드사(혹은 간편결제사) 대비 선택한 카드(혹은 간편결제)가 차지하는 비율을 거래액과 거래건수별로 비교할 수 있습니다.
  - 해외 통화의 경우, \[카드결제] \[간편결제] 상세 페이지는 표기되지 않습니다.
  - 카드결제는 발행사(publisher) 기준으로 표기됩니다.
    - 국내카드
      - 신한, 삼성, 현대, 비씨, KB국민, 롯데, 우리, 하나, NH농협
    - 해외카드
      - Visa, Master, Amex, JCB, Diners, UnionPay, 기타 해외
    - 기타
      - 시티카드, 은행카드, 혹은 카드사명을 알 수 없는 경우, 기타로 표기됩니다.
  - 간편결제는 payment\_method 혹은 pg\_provider가 간편결제로 지정된 경우를 기준으로 표기됩니다.
    - 카카오페이, 네이버페이, KB앱카드, 토스페이, 삼성페이, 애플페이, SSG Pay, 페이코
    - 기타
      - 위 8개 간편결제사 이외의 경우 및 간편결제사 명을 알 수 없는 경우,기타로 표기됩니다.

**Section 3. 결제대행사**

- 목적
  - 사용하고 있는 전체 결제대행사별 순위 및 기간별 변화 추이를 확인하고 어떤 결제대행사가 인기있는지 파악할 수 있습니다. 여러 결제대행사를 동시에 사용하고 있는 경우, 대행사별 효과 측정에 용이합니다.



- 데이터 표기 기준
  - 국내결제, 해외결제 모두 연동되어 있는 결제대행사를 기준으로 표기됩니다.

**Section 4. 결제전환율 (coming soon)**

- 목적
  - 결제 상태별 현황 및 비중을 파악할 수 있습니다. 결제 상태별 상세 현황과 타사 비교 벤치마크를 통해 현재 자사 결제전환율이 건강한지 파악하고, 결제 실패 사유를 심층 분석합니다.

### **결제 모니터링 서비스 (coming soon)**

- 목적
  - 실시간 / 기간별 결제 모니터링 서비스를 통해서 결제 이상 유무 및 장애 여부를 파악할 수 있습니다.



##### **Section 1. 실시간 결제 모니터링**

- 결제 상태 현황
  - 결제 상태별 거래건수를 실시간으로 확인할 수 있습니다.
- 웹훅 수신 현황
  - 포트원으로부터 수신한 웹훅에 대해 응답한 웹훅의 상태코드를 (http status )확인할 수 있습니다.
- 결제대행사별 결제성공률
  - 연동한 모든 결제대행사의 결제성공률을 실시간으로 확인할 수 있습니다.
- 웹훅 발송 현황
  - 웹훅 발송 성공률을 실시간으로 확인할 수 있습니다.

##### **Section 2. 기간별 결제 모니터링**

- 결제 상태별 거래현황
  - 선택한 날짜에 대한 결제 상태별 거래건수를 확인할 수 있습니다.
- 시간대별 웹훅 수신 및 발송 현황
  - 선택한 날짜에 대한 고객사 수신 웹훅 건수와 고객사 발송 웹훅 에러코드를 비교할 수 있습니다.



### **부가 설명**

#### **1.계정 설정**

- 권한 부여

<Indent level="1">

- 표기되는 데이터는 상위 상점 단위를 기준으로 하며, 하위 상점은 상위 상점에에 종속됩니다. 이는 관리자 콘솔과 동일한 방식입니다.
- 권한
  - Owner/Admin (=상위 상점) 계정이 모든 데이터를 소유합니다.
  - Manager / Dev, Read only(=하위 상점) 계정은 상위 상점에 종속됩니다.
  - Owner 계정이 [관리자콘솔 ↗](https://admin.portone.io/merchant) 접속하여 하위 상점을 추가하는 경우, 하위 상점은 별도의 가입을 하지 않아도 owner 계정은 모든 데이터 볼 수 있습니다.

</Indent>

- 과금 방식

<Indent level="1">

- 베타 서비스 기간 중에는 계정 추가 시에도 별도의 추가 과금은 없습니다.
- 정식 서비스 런칭 이후의 과금 정책은 포트원 어카운트 담당자를 통해서 별도 안내 드릴 예정입니다.

</Indent>

#### **2. 결제 데이터 분석 FAQ**

- **베타 서비스는 유료인가요, 무료인가요?**\
  \> 베타 서비스는 모두 무료입니다! 베타 서비스가 종료되고 정식으로 서비스가 런칭되면 유료로 전환됩니다.

* **하위상점이 있는 경우 신청은 한번만 하면 될까요?**\
  \> 네, 하나의 Owner 계정 내 여러개의 하위상점이 있는 경우, 상위 권한의 계정에서 한번만 신청해주시면 됩니다.

- **상위상점와 하위상점에서 결제데이터를 볼 수 있는 범위는 어떤 차이가 있을까요?**\
  \> 상위상점 : 상위상점의 거래 + 하위상점의 모든 거래에 대한 데이터 확인 가능\
  \> 하위상점 : 해당 상점(하위)의 데이터만 확인 가능

* **결제상태별 정의가 어떻게 되나요?**



- **거래데이터는 취소된 금액까지 포함하고 있나요?**\
  \> 기본적으로 취소된 금액을 포함한 데이터를 보여드리고 있으나, 원하시면 토글로 ON/OFF 하여 데이터를 확인하실 수 있습니다.

* **관리자콘솔 홈(대시보드) 및 결제내역과의 데이터 차이가 있는데 어떤 이유로 차이가 발생되나요?**

